#  Copyright 2023-2024 Amazon.com, Inc. or its affiliates.

"""This file was generated by xsdata, v23.8, on 2023-10-05 09:59:45

Generator: DataclassGenerator
See: https://xsdata.readthedocs.io/
"""
from enum import Enum

__NAMESPACE__ = "urn:us:gov:ic:ism-cvenum"


class CVEnumISMDissemValuesvalue(Enum):
    """
    :cvar FOUO: FOR OFFICIAL USE ONLY
    :cvar OC: ORIGINATOR CONTROLLED
    :cvar IMC: CONTROLLED IMAGERY
    :cvar SAMI: SOURCES AND METHODS INFORMATION
    :cvar NF: NOT RELEASABLE TO FOREIGN NATIONALS
    :cvar PR: CAUTION-PROPRIETARY INFORMATION INVOLVED
    :cvar REL: AUTHORIZED FOR RELEASE TO
    :cvar RELIDO: RELEASABLE BY INFORMATION DISCLOSURE OFFICIAL
    :cvar RD: RESTRICTED DATA
    :cvar RD_CNWDI: RD-CRITICAL NUCLEAR WEAPON DESIGN INFORMATION
    :cvar FRD: FORMERLY RESTRICTED DATA
    :cvar DCNI: DoD CONTROLLED NUCLEAR INFORMATION
    :cvar UCNI: DoE CONTROLLED NUCLEAR INFORMATION
    :cvar EYES: EYES ONLY
    :cvar DSEN: DEA SENSITIVE
    :cvar FISA: FOREIGN INTELLIGENCE SURVEILLANCE ACT
    """

    FOUO = "FOUO"
    OC = "OC"
    IMC = "IMC"
    SAMI = "SAMI"
    NF = "NF"
    PR = "PR"
    REL = "REL"
    RELIDO = "RELIDO"
    RD = "RD"
    RD_CNWDI = "RD-CNWDI"
    FRD = "FRD"
    DCNI = "DCNI"
    UCNI = "UCNI"
    EYES = "EYES"
    DSEN = "DSEN"
    FISA = "FISA"
