#  Copyright 2023-2024 Amazon.com, Inc. or its affiliates.

"""This file was generated by xsdata, v23.8, on 2023-10-05 09:59:45

Generator: DataclassGenerator
See: https://xsdata.readthedocs.io/
"""
from enum import Enum

__NAMESPACE__ = "urn:us:gov:ic:ism-cvenum"


class CVEnumISMSourceMarked(Enum):
    """(U) All currently authorized Source Marked values
    PERMISSIBLE VALUES
    The permissible values for this simple type are defined in the Controlled Value Enumeration:
    CVEnumISMSourceMarked.xml

    :cvar OADR: Source Marked OADR (Originating Agency's Determination Required)
    :cvar X1: Source Marked X1
    :cvar X2: Source Marked X2
    :cvar X3: Source Marked X3
    :cvar X4: Source Marked X4
    :cvar X5: Source Marked X5
    :cvar X6: Source Marked X6
    :cvar X7: Source Marked X7
    :cvar X8: Source Marked X8
    """

    OADR = "OADR"
    X1 = "X1"
    X2 = "X2"
    X3 = "X3"
    X4 = "X4"
    X5 = "X5"
    X6 = "X6"
    X7 = "X7"
    X8 = "X8"
