#  Copyright 2023-2024 Amazon.com, Inc. or its affiliates.

"""This file was generated by xsdata, v23.8, on 2023-10-05 09:59:45

Generator: DataclassGenerator
See: https://xsdata.readthedocs.io/
"""
from enum import Enum

__NAMESPACE__ = "urn:us:gov:ic:cvenum:ism:notice"


class CVEnumISMNoticeValues(Enum):
    """(U) All currently authorized Notice values
    PERMISSIBLE VALUES
    The permissible values for this simple type are defined in the Controlled Value Enumeration:
    CVEnumISMNotice.xml

    :cvar FISA: FISA Warning statement
    :cvar IMC: IMCON Warning statement
    :cvar CNWDI: Controled Nuclear Weapon Design Information Warning statement
    :cvar RD: RD Warning statement
    :cvar FRD: FRD Warning statement
    :cvar DS: LIMDIS caveat
    :cvar LES: LES Notice
    :cvar LES_NF: LES-NF Notice
    :cvar DSEN: DSEN Notice
    :cvar DO_D_DIST_A: DoD Distribution statement A from DoD Directive 5230.24
    :cvar DO_D_DIST_B: DoD Distribution statement B from DoD Directive 5230.24
    :cvar DO_D_DIST_C: DoD Distribution statement C from DoD Directive 5230.24
    :cvar DO_D_DIST_D: DoD Distribution statement D from DoD Directive 5230.24
    :cvar DO_D_DIST_E: DoD Distribution statement E from DoD Directive 5230.24
    :cvar DO_D_DIST_F: DoD Distribution statement F from DoD Directive 5230.24
    :cvar DO_D_DIST_X: DoD Distribution statement X from DoD Directive 5230.24
    :cvar US_PERSON: US Person info Notice
    :cvar PRE13526_ORCON: Indicates that an instance document must abide by rules pertaining to ORIGINATOR
        CONTROLLED data issued prior to Executive Order 13526.
    :cvar POC: Indicates that the contents of this notice specify the contact information for a required point-
        of-contact.
    :cvar COMSEC: COMSEC Notice
    """

    FISA = "FISA"
    IMC = "IMC"
    CNWDI = "CNWDI"
    RD = "RD"
    FRD = "FRD"
    DS = "DS"
    LES = "LES"
    LES_NF = "LES-NF"
    DSEN = "DSEN"
    DO_D_DIST_A = "DoD-Dist-A"
    DO_D_DIST_B = "DoD-Dist-B"
    DO_D_DIST_C = "DoD-Dist-C"
    DO_D_DIST_D = "DoD-Dist-D"
    DO_D_DIST_E = "DoD-Dist-E"
    DO_D_DIST_F = "DoD-Dist-F"
    DO_D_DIST_X = "DoD-Dist-X"
    US_PERSON = "US-Person"
    PRE13526_ORCON = "pre13526ORCON"
    POC = "POC"
    COMSEC = "COMSEC"
