#  Copyright 2023-2024 Amazon.com, Inc. or its affiliates.

"""This file was generated by xsdata, v23.8, on 2023-10-05 09:59:45

Generator: DataclassGenerator
See: https://xsdata.readthedocs.io/
"""
from enum import Enum

__NAMESPACE__ = "urn:us:gov:ic:ism-cvenum"


class CVEnumISMSCIControlsValuesvalue(Enum):
    """
    :cvar HCS: HCS
    :cvar KDK: Klondike
    :cvar SI: COMINT
    :cvar SI_G: SI-GAMMA
    :cvar TK: TALENT KEYHOLE
    """

    HCS = "HCS"
    KDK = "KDK"
    SI = "SI"
    SI_G = "SI-G"
    TK = "TK"
