#  Copyright 2023-2024 Amazon.com, Inc. or its affiliates.

"""This file was generated by xsdata, v23.8, on 2023-10-05 09:59:45

Generator: DataclassGenerator
See: https://xsdata.readthedocs.io/
"""
from enum import Enum

__NAMESPACE__ = "urn:us:gov:ic:ism-cvenum"


class CVEnumISMNonICValues(Enum):
    """(U) All currently valid Non-IC markings from the published register
    PERMISSIBLE VALUES
    The permissible values for this simple type are defined in the Controlled Value Enumeration:
    CVEnumISMNonIC.xml

    :cvar SC: SPECIAL CATEGORY
    :cvar SINFO: SENSITIVE INFORMATION
    :cvar DS: LIMITED DISTRIBUTION
    :cvar XD: EXCLUSIVE DISTRIBUTION
    :cvar ND: NO DISTRIBUTION
    :cvar SBU: SENSITIVE BUT UNCLASSIFIED
    :cvar SBU_NF: SENSITIVE BUT UNCLASSIFIED NOFORN
    :cvar LES: LAW ENFORCEMENT SENSITIVE
    :cvar LES_NF: LAW ENFORCEMENT SENSITIVE NOFORN
    """

    SC = "SC"
    SINFO = "SINFO"
    DS = "DS"
    XD = "XD"
    ND = "ND"
    SBU = "SBU"
    SBU_NF = "SBU-NF"
    LES = "LES"
    LES_NF = "LES-NF"
