#  Copyright 2023-2024 Amazon.com, Inc. or its affiliates.

"""This file was generated by xsdata, v23.8, on 2023-10-05 09:59:45

Generator: DataclassGenerator
See: https://xsdata.readthedocs.io/
"""
from enum import Enum

__NAMESPACE__ = "urn:us:gov:ic:cvenum:ism:complieswith"


class CVEnumISMCompliesWithValues(Enum):
    """(U) ISM rule sets documents may comply with.

    PERMISSIBLE VALUES
    The permissible values for this simple type are defined in the Controlled Value Enumeration:
    CVEnumISMCompliesWith.xml

    :cvar USGOV: Document claims compliance with all rules encoded in ISM for documents produced by the US
        Federal Government. This is the minimum set of rules for US documents to adhere to, and all US documents
        should claim compliance with USGov. For example, a US Intelligence Community document should claim
        ism:compliesWith="USGov USIC".
    :cvar USIC: Document claims compliance with all rules encoded in ISM for documents produced by the US
        Intelligence Community. Documents that claim compliance with USIC MUST also claim compliance with USGov.
    :cvar USDOD: Document claims compliance with all rules encoded in ISM for documents produced by the US
        Department of Defense. Documents that claim compliance with USDOD MUST also claim compliance with USGov.
    :cvar OTHER_AUTHORITY: Document claims compliance with an authority other than the USGov, USIC, or USDOD.
        This token is not allowed if the ism:ownerProducer contains USA.
    """

    USGOV = "USGov"
    USIC = "USIC"
    USDOD = "USDOD"
    OTHER_AUTHORITY = "OtherAuthority"
