#  Copyright 2023-2024 Amazon.com, Inc. or its affiliates.

"""This file was generated by xsdata, v23.8, on 2023-10-05 09:59:45

Generator: DataclassGenerator
See: https://xsdata.readthedocs.io/
"""
from enum import Enum

__NAMESPACE__ = "urn:us:gov:ic:cvenum:ism:scicontrols"


class CVEnumISMSCIControlsValuesvalue(Enum):
    """
    :cvar EL: ENDSEAL
    :cvar EL_EU: ECRU
    :cvar EL_NK: NONBOOK
    :cvar HCS: HCS
    :cvar HCS_O: HCS-O
    :cvar HCS_P: HCS-P
    :cvar KDK: KLONDIKE
    :cvar KDK_BLFH: KDK BLUEFISH
    :cvar KDK_IDIT: KDK IDITAROD
    :cvar KDK_KAND: KDK KANDIK
    :cvar RSV: RESERVE
    :cvar SI: SPECIAL INTELLIGENCE
    :cvar SI_G: SI-GAMMA
    :cvar TK: TALENT KEYHOLE
    """

    EL = "EL"
    EL_EU = "EL-EU"
    EL_NK = "EL-NK"
    HCS = "HCS"
    HCS_O = "HCS-O"
    HCS_P = "HCS-P"
    KDK = "KDK"
    KDK_BLFH = "KDK-BLFH"
    KDK_IDIT = "KDK-IDIT"
    KDK_KAND = "KDK-KAND"
    RSV = "RSV"
    SI = "SI"
    SI_G = "SI-G"
    TK = "TK"
