#  Copyright 2023-2024 Amazon.com, Inc. or its affiliates.

"""This file was generated by xsdata, v23.8, on 2023-10-05 09:59:45

Generator: DataclassGenerator
See: https://xsdata.readthedocs.io/
"""
from enum import Enum

__NAMESPACE__ = "urn:us:gov:ic:cvenum:ism:exemptfrom"


class CVEnumISMExemptFromValues(Enum):
    """(U) Current rule set names that documents may comply
    with
    PERMISSIBLE VALUES
    The permissible values for this simple type are defined in the Controlled Value Enumeration:
    CVEnumISMExemptFrom.xml

    :cvar IC_710_MANDATORY_FDR: Document claims exemption from ICD-710 rules mandating the use of Foreign
        Disclosure and Release markings that have been encoded in ISM. Currently, the requirement for FD&amp;R is
        only mandatory for Disseminated Analytic Product; however, it is strongly encouraged otherwise.
    :cvar DOD_DISTRO_STATEMENT: Document claims exemption from the rules in DoD5230.24 requiring DoD Distribution
        Statements that have been encoded into ISM.
    """

    IC_710_MANDATORY_FDR = "IC_710_MANDATORY_FDR"
    DOD_DISTRO_STATEMENT = "DOD_DISTRO_STATEMENT"
