#  Copyright 2023-2024 Amazon.com, Inc. or its affiliates.

"""This file was generated by xsdata, v23.8, on 2023-10-05 09:59:45

Generator: DataclassGenerator
See: https://xsdata.readthedocs.io/
"""
from enum import Enum

__NAMESPACE__ = "urn:us:gov:ic:cvenum:ismcat:relto"


class CVEnumISMCATRelToValuesvalue(Enum):
    """
    :cvar USA: United States
    :cvar ABW: Aruba
    :cvar AFG: Islamic Republic of Afghanistan
    :cvar AGO: Republic of Angola
    :cvar AIA: Anguilla
    :cvar ALB: Republic of Albania
    :cvar AND: Principality of Andorra
    :cvar ARE: United Arab Emirates
    :cvar ARG: Argentine Republic
    :cvar ARM: Republic of Armenia
    :cvar ASM: Territory of American Samoa
    :cvar ATA: Antarctica
    :cvar ATF: French Southern and Antarctic Lands
    :cvar ATG: Antigua and Barbuda
    :cvar AUS: Commonwealth of Australia
    :cvar AUT: Republic of Austria
    :cvar AX2: Guantanamo Bay Naval Base
    :cvar AZE: Republic of Azerbaijan
    :cvar BDI: Republic of Burundi
    :cvar BEL: Kingdom of Belgium
    :cvar BEN: Republic of Benin
    :cvar BES: Bonaire, Sint Eustatius, and Saba
    :cvar BFA: Burkina Faso
    :cvar BGD: People's Republic of Bangladesh
    :cvar BGR: Republic of Bulgaria
    :cvar BHR: Kingdom of Bahrain
    :cvar BHS: Commonwealth of The Bahamas
    :cvar BIH: Bosnia and Herzegovina
    :cvar BLM: Saint Barthelemy
    :cvar BLR: Republic of Belarus
    :cvar BLZ: Belize
    :cvar BMU: Bermuda
    :cvar BOL: Plurinational State of Bolivia
    :cvar BRA: Federative Republic of Brazil
    :cvar BRB: Barbados
    :cvar BRN: Brunei Darussalam
    :cvar BTN: Kingdom of Bhutan
    :cvar BVT: Bouvet Island
    :cvar BWA: Republic of Botswana
    :cvar CAF: Central African Republic
    :cvar CAN: Canada
    :cvar CCK: Territory of Cocos (Keeling) Islands
    :cvar CHE: Swiss Confederation
    :cvar CHL: Republic of Chile
    :cvar CHN: People's Republic of China
    :cvar CIV: Republic of Côte d'Ivoire
    :cvar CMR: Republic of Cameroon
    :cvar COD: Democratic Republic of the Congo
    :cvar COG: Republic of the Congo
    :cvar COK: Cook Islands
    :cvar COL: Republic of Colombia
    :cvar COM: Union of the Comoros
    :cvar CPT: Clipperton Island
    :cvar CPV: Republic of Cape Verde
    :cvar CRI: Republic of Costa Rica
    :cvar CUB: Republic of Cuba
    :cvar CUW: Curaçao
    :cvar CXR: Territory of Christmas Island
    :cvar CYM: Cayman Islands
    :cvar CYP: Republic of Cyprus
    :cvar CZE: Czech Republic
    :cvar DEU: Federal Republic of Germany
    :cvar DGA: Diego Garcia
    :cvar DJI: Republic of Djibouti
    :cvar DMA: Commonwealth of Dominica
    :cvar DNK: Kingdom of Denmark
    :cvar DOM: Dominican Republic
    :cvar DZA: People's Democratic Republic of Algeria
    :cvar ECU: Republic of Ecuador
    :cvar EGY: Arab Republic of Egypt
    :cvar ERI: State of Eritrea
    :cvar ESH: Western Sahara
    :cvar ESP: Kingdom of Spain
    :cvar EST: Republic of Estonia
    :cvar ETH: Federal Democratic Republic of Ethiopia
    :cvar FIN: Republic of Finland
    :cvar FJI: Republic of Fiji
    :cvar FLK: Falkland Islands (Islas Malvinas)
    :cvar FRA: French Republic
    :cvar FRO: Faroe Islands
    :cvar FSM: Federated States of Micronesia
    :cvar GAB: Gabonese Republic
    :cvar GBR: United Kingdom of Great Britain and Northern Ireland
    :cvar GEO: Georgia
    :cvar GGY: Bailiwick of Guernsey
    :cvar GHA: Republic of Ghana
    :cvar GIB: Gibraltar
    :cvar GIN: Republic of Guinea
    :cvar GLP: Department of Guadeloupe
    :cvar GMB: Republic of The Gambia
    :cvar GNB: Republic of Guinea-Bissau
    :cvar GNQ: Republic of Equatorial Guinea
    :cvar GRC: Hellenic Republic
    :cvar GRD: Grenada
    :cvar GRL: Greenland
    :cvar GTM: Republic of Guatemala
    :cvar GUF: Department of Guiana
    :cvar GUM: Territory of Guam
    :cvar GUY: Co-operative Republic of Guyana
    :cvar HKG: Hong Kong Special Administrative Region
    :cvar HMD: Territory of Heard Island and McDonald Islands
    :cvar HND: Republic of Honduras
    :cvar HRV: Republic of Croatia
    :cvar HTI: Republic of Haiti
    :cvar HUN: Hungary
    :cvar IDN: Republic of Indonesia
    :cvar IMN: Isle of Man
    :cvar IND: Republic of India
    :cvar IOT: British Indian Ocean Territory
    :cvar IRL: Ireland
    :cvar IRN: Islamic Republic of Iran
    :cvar IRQ: Republic of Iraq
    :cvar ISL: Republic of Iceland
    :cvar ISR: State of Israel
    :cvar ITA: Italian Republic
    :cvar JAM: Jamaica
    :cvar JEY: Bailiwick of Jersey
    :cvar JOR: Hashemite Kingdom of Jordan
    :cvar JPN: Japan
    :cvar KAZ: Republic of Kazakhstan
    :cvar KEN: Republic of Kenya
    :cvar KGZ: Kyrgyz Republic
    :cvar KHM: Kingdom of Cambodia
    :cvar KIR: Republic of Kiribati
    :cvar KNA: Federation of Saint Kitts and Nevis
    :cvar KOR: Republic of Korea
    :cvar KWT: State of Kuwait
    :cvar LAO: Lao People's Democratic Republic
    :cvar LBN: Lebanese Republic
    :cvar LBR: Republic of Liberia
    :cvar LBY: Libya
    :cvar LCA: Saint Lucia
    :cvar LIE: Principality of Liechtenstein
    :cvar LKA: Democratic Socialist Republic of Sri Lanka
    :cvar LSO: Kingdom of Lesotho
    :cvar LTU: Republic of Lithuania
    :cvar LUX: Grand Duchy of Luxembourg
    :cvar LVA: Republic of Latvia
    :cvar MAC: Macau Special Administrative Region
    :cvar MAF: Saint Martin
    :cvar MAR: Kingdom of Morocco
    :cvar MCO: Principality of Monaco
    :cvar MDA: Republic of Moldova
    :cvar MDG: Republic of Madagascar
    :cvar MDV: Republic of Maldives
    :cvar MEX: United Mexican States
    :cvar MHL: Republic of the Marshall Islands
    :cvar MKD: Republic of Macedonia
    :cvar MLI: Republic of Mali
    :cvar MLT: Republic of Malta
    :cvar MMR: Union of Burma
    :cvar MNE: Montenegro
    :cvar MNG: Mongolia
    :cvar MNP: Commonwealth of the Northern Mariana Islands
    :cvar MOZ: Republic of Mozambique
    :cvar MRT: Islamic Republic of Mauritania
    :cvar MSR: Montserrat
    :cvar MTQ: Department of Martinique
    :cvar MUS: Republic of Mauritius
    :cvar MWI: Republic of Malawi
    :cvar MYS: Malaysia
    :cvar MYT: Department of Mayotte
    :cvar NAM: Republic of Namibia
    :cvar NCL: New Caledonia
    :cvar NER: Republic of the Niger
    :cvar NFK: Territory of Norfolk Island
    :cvar NGA: Federal Republic of Nigeria
    :cvar NIC: Republic of Nicaragua
    :cvar NIU: Niue
    :cvar NLD: Kingdom of the Netherlands
    :cvar NOR: Kingdom of Norway
    :cvar NPL: Federal Democratic Republic of Nepal
    :cvar NRU: Republic of Nauru
    :cvar NZL: New Zealand
    :cvar OMN: Sultanate of Oman
    :cvar PAK: Islamic Republic of Pakistan
    :cvar PAN: Republic of Panama
    :cvar PCN: Pitcairn, Henderson, Ducie, and Oeno Islands
    :cvar PER: Republic of Peru
    :cvar PHL: Republic of the Philippines
    :cvar PLW: Republic of Palau
    :cvar PNG: Independent State of Papua New Guinea
    :cvar POL: Republic of Poland
    :cvar PRI: Commonwealth of Puerto Rico
    :cvar PRK: Democratic People's Republic of Korea
    :cvar PRT: Portuguese Republic
    :cvar PRY: Republic of Paraguay
    :cvar PSE: Palestinian Territory
    :cvar PYF: French Polynesia
    :cvar QAT: State of Qatar
    :cvar REU: Department of Reunion
    :cvar ROU: Romania
    :cvar RUS: Russian Federation
    :cvar RWA: Republic of Rwanda
    :cvar SAU: Kingdom of Saudi Arabia
    :cvar SDN: Republic of the Sudan
    :cvar SEN: Republic of Senegal
    :cvar SGP: Republic of Singapore
    :cvar SGS: South Georgia and South Sandwich Islands
    :cvar SHN: Saint Helena, Ascension, and Tristan da Cunha
    :cvar SLB: Solomon Islands
    :cvar SLE: Republic of Sierra Leone
    :cvar SLV: Republic of El Salvador
    :cvar SMR: Republic of San Marino
    :cvar SOM: Somalia, Federal Republic of
    :cvar SPM: Territorial Collectivity of Saint Pierre and Miquelon
    :cvar SRB: Republic of Serbia
    :cvar SSD: Republic of South Sudan
    :cvar STP: Democratic Republic of Sao Tome and Principe
    :cvar SUR: Republic of Suriname
    :cvar SVK: Slovak Republic
    :cvar SVN: Republic of Slovenia
    :cvar SWE: Kingdom of Sweden
    :cvar SWZ: Kingdom of Swaziland
    :cvar SXM: Sint Maarten
    :cvar SYC: Republic of Seychelles
    :cvar SYR: Syrian Arab Republic
    :cvar TCA: Turks and Caicos Islands
    :cvar TCD: Republic of Chad
    :cvar TGO: Togolese Republic
    :cvar THA: Kingdom of Thailand
    :cvar TJK: Republic of Tajikistan
    :cvar TKL: Tokelau
    :cvar TKM: Turkmenistan
    :cvar TLS: Democratic Republic of Timor-Leste
    :cvar TON: Kingdom of Tonga
    :cvar TTO: Republic of Trinidad and Tobago
    :cvar TUN: Tunisian Republic
    :cvar TUR: Republic of Turkey
    :cvar TUV: Tuvalu
    :cvar TWN: Taiwan
    :cvar TZA: United Republic of Tanzania
    :cvar UGA: Republic of Uganda
    :cvar UKR: Ukraine
    :cvar URY: Oriental Republic of Uruguay
    :cvar UZB: Republic of Uzbekistan
    :cvar VAT: State of the Vatican City
    :cvar VCT: Saint Vincent and the Grenadines
    :cvar VEN: Bolivarian Republic of Venezuela
    :cvar VGB: Virgin Islands, British
    :cvar VIR: United States Virgin Islands
    :cvar VNM: Socialist Republic of Vietnam
    :cvar VUT: Republic of Vanuatu
    :cvar WLF: Wallis and Futuna
    :cvar WSM: Independent State of Samoa
    :cvar XAC: Territory of Ashmore and Cartier Islands
    :cvar XAZ: Entity 1
    :cvar XBI: Bassas da India
    :cvar XBK: Baker Island
    :cvar XCR: Entity 2
    :cvar XCS: Coral Sea Islands Territory
    :cvar XCY: Entity 3
    :cvar XEU: Europa Island
    :cvar XGL: Glorioso Islands
    :cvar XGZ: Gaza Strip
    :cvar XHO: Howland Island
    :cvar XJA: Johnston Atoll
    :cvar XJM: Jan Mayen
    :cvar XJN: Juan de Nova Island
    :cvar XJV: Jarvis Island
    :cvar XKM: Entity 4
    :cvar XKN: Entity 5
    :cvar XKR: Kingman Reef
    :cvar XKS: Republic of Kosovo
    :cvar XMW: Midway Islands
    :cvar XNV: Navassa Island
    :cvar XPL: Palmyra Atoll
    :cvar XPR: Paracel Islands
    :cvar XQP: Etorofu, Habomai, Kunashiri, and Shikotan Islands
    :cvar XQZ: Akrotiri
    :cvar XSP: Spratly Islands
    :cvar XSV: Svalbard
    :cvar XTR: Tromelin Island
    :cvar XWB: West Bank
    :cvar XWK: Wake Island
    :cvar XXD: Dhekelia
    :cvar XXX: No Man's Land
    :cvar YEM: Republic of Yemen
    :cvar ZAF: Republic of South Africa
    :cvar ZMB: Republic of Zambia
    :cvar ZWE: Republic of Zimbabwe
    :cvar ACGU: FOUR EYES
    :cvar APFS: Suppressed
    :cvar BWCS: Biological Weapons Convention States
    :cvar CFCK: ROK/US Combined Forces Command, Korea
    :cvar CMFC: Combined Maritime Forces Central
    :cvar CMFP: Cooperative Maritime Forces Pacific
    :cvar CPMT: Civilian Protection Monitoring Team for Sudan
    :cvar CTOC: Countering Transnational Organized Crime
    :cvar CWCS: Chemical Weapons Convention States
    :cvar FVEY: FIVE EYES
    :cvar GCTF: Global Counter-Terrorism Forces
    :cvar GMIF: Global Maritime Interception Forces
    :cvar ISAF: International Security Assistance Force for Afghanistan
    :cvar KFOR: Stabilization Forces in Kosovo
    :cvar MLEC: Multi-Lateral Enduring Contingency
    :cvar NACT: North African Counter-Terrorism Forces
    :cvar NATO: North Atlantic Treaty Organization
    :cvar NCFE: NATO Convention Armed Forces in Europe
    :cvar OSTY: Open Skies Treaty
    :cvar SPAA: Suppressed
    :cvar TEYE: THREE EYES
    :cvar UNCK: United Nations Command, Korea
    """

    USA = "USA"
    ABW = "ABW"
    AFG = "AFG"
    AGO = "AGO"
    AIA = "AIA"
    ALB = "ALB"
    AND = "AND"
    ARE = "ARE"
    ARG = "ARG"
    ARM = "ARM"
    ASM = "ASM"
    ATA = "ATA"
    ATF = "ATF"
    ATG = "ATG"
    AUS = "AUS"
    AUT = "AUT"
    AX2 = "AX2"
    AZE = "AZE"
    BDI = "BDI"
    BEL = "BEL"
    BEN = "BEN"
    BES = "BES"
    BFA = "BFA"
    BGD = "BGD"
    BGR = "BGR"
    BHR = "BHR"
    BHS = "BHS"
    BIH = "BIH"
    BLM = "BLM"
    BLR = "BLR"
    BLZ = "BLZ"
    BMU = "BMU"
    BOL = "BOL"
    BRA = "BRA"
    BRB = "BRB"
    BRN = "BRN"
    BTN = "BTN"
    BVT = "BVT"
    BWA = "BWA"
    CAF = "CAF"
    CAN = "CAN"
    CCK = "CCK"
    CHE = "CHE"
    CHL = "CHL"
    CHN = "CHN"
    CIV = "CIV"
    CMR = "CMR"
    COD = "COD"
    COG = "COG"
    COK = "COK"
    COL = "COL"
    COM = "COM"
    CPT = "CPT"
    CPV = "CPV"
    CRI = "CRI"
    CUB = "CUB"
    CUW = "CUW"
    CXR = "CXR"
    CYM = "CYM"
    CYP = "CYP"
    CZE = "CZE"
    DEU = "DEU"
    DGA = "DGA"
    DJI = "DJI"
    DMA = "DMA"
    DNK = "DNK"
    DOM = "DOM"
    DZA = "DZA"
    ECU = "ECU"
    EGY = "EGY"
    ERI = "ERI"
    ESH = "ESH"
    ESP = "ESP"
    EST = "EST"
    ETH = "ETH"
    FIN = "FIN"
    FJI = "FJI"
    FLK = "FLK"
    FRA = "FRA"
    FRO = "FRO"
    FSM = "FSM"
    GAB = "GAB"
    GBR = "GBR"
    GEO = "GEO"
    GGY = "GGY"
    GHA = "GHA"
    GIB = "GIB"
    GIN = "GIN"
    GLP = "GLP"
    GMB = "GMB"
    GNB = "GNB"
    GNQ = "GNQ"
    GRC = "GRC"
    GRD = "GRD"
    GRL = "GRL"
    GTM = "GTM"
    GUF = "GUF"
    GUM = "GUM"
    GUY = "GUY"
    HKG = "HKG"
    HMD = "HMD"
    HND = "HND"
    HRV = "HRV"
    HTI = "HTI"
    HUN = "HUN"
    IDN = "IDN"
    IMN = "IMN"
    IND = "IND"
    IOT = "IOT"
    IRL = "IRL"
    IRN = "IRN"
    IRQ = "IRQ"
    ISL = "ISL"
    ISR = "ISR"
    ITA = "ITA"
    JAM = "JAM"
    JEY = "JEY"
    JOR = "JOR"
    JPN = "JPN"
    KAZ = "KAZ"
    KEN = "KEN"
    KGZ = "KGZ"
    KHM = "KHM"
    KIR = "KIR"
    KNA = "KNA"
    KOR = "KOR"
    KWT = "KWT"
    LAO = "LAO"
    LBN = "LBN"
    LBR = "LBR"
    LBY = "LBY"
    LCA = "LCA"
    LIE = "LIE"
    LKA = "LKA"
    LSO = "LSO"
    LTU = "LTU"
    LUX = "LUX"
    LVA = "LVA"
    MAC = "MAC"
    MAF = "MAF"
    MAR = "MAR"
    MCO = "MCO"
    MDA = "MDA"
    MDG = "MDG"
    MDV = "MDV"
    MEX = "MEX"
    MHL = "MHL"
    MKD = "MKD"
    MLI = "MLI"
    MLT = "MLT"
    MMR = "MMR"
    MNE = "MNE"
    MNG = "MNG"
    MNP = "MNP"
    MOZ = "MOZ"
    MRT = "MRT"
    MSR = "MSR"
    MTQ = "MTQ"
    MUS = "MUS"
    MWI = "MWI"
    MYS = "MYS"
    MYT = "MYT"
    NAM = "NAM"
    NCL = "NCL"
    NER = "NER"
    NFK = "NFK"
    NGA = "NGA"
    NIC = "NIC"
    NIU = "NIU"
    NLD = "NLD"
    NOR = "NOR"
    NPL = "NPL"
    NRU = "NRU"
    NZL = "NZL"
    OMN = "OMN"
    PAK = "PAK"
    PAN = "PAN"
    PCN = "PCN"
    PER = "PER"
    PHL = "PHL"
    PLW = "PLW"
    PNG = "PNG"
    POL = "POL"
    PRI = "PRI"
    PRK = "PRK"
    PRT = "PRT"
    PRY = "PRY"
    PSE = "PSE"
    PYF = "PYF"
    QAT = "QAT"
    REU = "REU"
    ROU = "ROU"
    RUS = "RUS"
    RWA = "RWA"
    SAU = "SAU"
    SDN = "SDN"
    SEN = "SEN"
    SGP = "SGP"
    SGS = "SGS"
    SHN = "SHN"
    SLB = "SLB"
    SLE = "SLE"
    SLV = "SLV"
    SMR = "SMR"
    SOM = "SOM"
    SPM = "SPM"
    SRB = "SRB"
    SSD = "SSD"
    STP = "STP"
    SUR = "SUR"
    SVK = "SVK"
    SVN = "SVN"
    SWE = "SWE"
    SWZ = "SWZ"
    SXM = "SXM"
    SYC = "SYC"
    SYR = "SYR"
    TCA = "TCA"
    TCD = "TCD"
    TGO = "TGO"
    THA = "THA"
    TJK = "TJK"
    TKL = "TKL"
    TKM = "TKM"
    TLS = "TLS"
    TON = "TON"
    TTO = "TTO"
    TUN = "TUN"
    TUR = "TUR"
    TUV = "TUV"
    TWN = "TWN"
    TZA = "TZA"
    UGA = "UGA"
    UKR = "UKR"
    URY = "URY"
    UZB = "UZB"
    VAT = "VAT"
    VCT = "VCT"
    VEN = "VEN"
    VGB = "VGB"
    VIR = "VIR"
    VNM = "VNM"
    VUT = "VUT"
    WLF = "WLF"
    WSM = "WSM"
    XAC = "XAC"
    XAZ = "XAZ"
    XBI = "XBI"
    XBK = "XBK"
    XCR = "XCR"
    XCS = "XCS"
    XCY = "XCY"
    XEU = "XEU"
    XGL = "XGL"
    XGZ = "XGZ"
    XHO = "XHO"
    XJA = "XJA"
    XJM = "XJM"
    XJN = "XJN"
    XJV = "XJV"
    XKM = "XKM"
    XKN = "XKN"
    XKR = "XKR"
    XKS = "XKS"
    XMW = "XMW"
    XNV = "XNV"
    XPL = "XPL"
    XPR = "XPR"
    XQP = "XQP"
    XQZ = "XQZ"
    XSP = "XSP"
    XSV = "XSV"
    XTR = "XTR"
    XWB = "XWB"
    XWK = "XWK"
    XXD = "XXD"
    XXX = "XXX"
    YEM = "YEM"
    ZAF = "ZAF"
    ZMB = "ZMB"
    ZWE = "ZWE"
    ACGU = "ACGU"
    APFS = "APFS"
    BWCS = "BWCS"
    CFCK = "CFCK"
    CMFC = "CMFC"
    CMFP = "CMFP"
    CPMT = "CPMT"
    CTOC = "CTOC"
    CWCS = "CWCS"
    FVEY = "FVEY"
    GCTF = "GCTF"
    GMIF = "GMIF"
    ISAF = "ISAF"
    KFOR = "KFOR"
    MLEC = "MLEC"
    NACT = "NACT"
    NATO = "NATO"
    NCFE = "NCFE"
    OSTY = "OSTY"
    SPAA = "SPAA"
    TEYE = "TEYE"
    UNCK = "UNCK"
