#  Copyright 2023-2024 Amazon.com, Inc. or its affiliates.

"""This file was generated by xsdata, v23.8, on 2023-10-05 09:58:35

Generator: DataclassGenerator
See: https://xsdata.readthedocs.io/
"""
# nothing here
