#  Copyright 2023-2024 Amazon.com, Inc. or its affiliates.

"""This file was generated by xsdata, v23.8, on 2023-10-05 09:59:45

Generator: DataclassGenerator
See: https://xsdata.readthedocs.io/
"""
from .cvenum_ismcatfgiopen import CVEnumISMCATFGIOpenValuesvalue
from .cvenum_ismcatfgiprotected import CVEnumISMCATFGIProtectedValuesvalue
from .cvenum_ismcatowner_producer import CVEnumISMCATOwnerProducerValuesvalue
from .cvenum_ismcatrel_to import CVEnumISMCATRelToValuesvalue

__all__ = [
    "CVEnumISMCATFGIOpenValuesvalue",
    "CVEnumISMCATFGIProtectedValuesvalue",
    "CVEnumISMCATOwnerProducerValuesvalue",
    "CVEnumISMCATRelToValuesvalue",
]
