#  Copyright 2023-2024 Amazon.com, Inc. or its affiliates.

"""This file was generated by xsdata, v23.8, on 2023-10-05 09:59:45

Generator: DataclassGenerator
See: https://xsdata.readthedocs.io/
"""
from enum import Enum

__NAMESPACE__ = "urn:us:gov:ic:cvenum:ism:atomicEnergyMarkings"


class CVEnumISMatomicEnergyMarkingsValuesvalue(Enum):
    """
    :cvar RD: RESTRICTED DATA
    :cvar RD_CNWDI: RD-CRITICAL NUCLEAR WEAPON DESIGN INFORMATION
    :cvar FRD: FORMERLY RESTRICTED DATA
    :cvar DCNI: DoD CONTROLLED NUCLEAR INFORMATION
    :cvar UCNI: DoE CONTROLLED NUCLEAR INFORMATION
    :cvar TFNI: TRANSCLASSIFIED FOREIGN NUCLEAR INFORMATION
    """

    RD = "RD"
    RD_CNWDI = "RD-CNWDI"
    FRD = "FRD"
    DCNI = "DCNI"
    UCNI = "UCNI"
    TFNI = "TFNI"
