#  Copyright 2023-2024 Amazon.com, Inc. or its affiliates.

"""This file was generated by xsdata, v23.8, on 2023-10-05 09:59:45

Generator: DataclassGenerator
See: https://xsdata.readthedocs.io/
"""
from enum import Enum

__NAMESPACE__ = "urn:us:gov:ic:ism-cvenum"


class CVEnumISMCompliesWithValues(Enum):
    """(U) Current rule set names that documents may comply with
    PERMISSIBLE VALUES
    The permissible values for this simple type are defined in the Controlled Value Enumeration:
    CVEnumISMCompliesWith.xml

    :cvar ICD_710: Document claims compliance with the rules in ICD-710 that have been encoded into ISM
    :cvar DO_D5230_24: Document claims compliance with the rules in DoD5230.24 that have been encoded into ISM
    """

    ICD_710 = "ICD-710"
    DO_D5230_24 = "DoD5230.24"
