#  Copyright 2023-2024 Amazon.com, Inc. or its affiliates.

"""This file was generated by xsdata, v23.8, on 2023-10-05 09:59:45

Generator: DataclassGenerator
See: https://xsdata.readthedocs.io/
"""
from enum import Enum

__NAMESPACE__ = "urn:us:gov:ic:ism-cvenum"


class CVEnumISM25X(Enum):
    """(U) All currently authorized 25X values.

    PERMISSIBLE VALUES
    The permissible values for this simple type are defined in the Controlled Value Enumeration:
    CVEnumISM25X.xml

    :cvar VALUE_25_X1: Reveal information about the application of an intelligence source or method.
    :cvar VALUE_25_X1_HUMAN: Reveal the identity of a confidential human source or human intelligence source.
    :cvar VALUE_25_X2: Reveal information that would assist in the development or use of weapons of mass
        destruction.
    :cvar VALUE_25_X3: Reveal information that would impair U.S. cryptologic systems or activities.
    :cvar VALUE_25_X4: Reveal information that would impair the application of state-of-the-art technology within
        a U.S. weapon system.
    :cvar VALUE_25_X5: Reveal actual U.S. military war plans that remain in effect.
    :cvar VALUE_25_X6: Reveal information, including foreign government information, that would seriously and
        demonstrably impair relations between the United States and a foreign government or seriously and
        demonstrably undermine ongoing diplomatic activities of the United States.
    :cvar VALUE_25_X7: Reveal information that would clearly and demonstrably impair the current ability of
        United States Government officials to protect the President, Vice President, or other protectees for whom
        protection services, in the interest of national security, are authorized.
    :cvar VALUE_25_X8: Reveal information that would seriously and demonstrably impair current national security
        emergency preparedness plans or reveal current vulnerabilities of systems, installations,
        infrastructures, or projects relating to the national security.
    :cvar VALUE_25_X9: Violate a statue, treaty, or international agreement.
    """

    VALUE_25_X1 = "25X1"
    VALUE_25_X1_HUMAN = "25X1-human"
    VALUE_25_X2 = "25X2"
    VALUE_25_X3 = "25X3"
    VALUE_25_X4 = "25X4"
    VALUE_25_X5 = "25X5"
    VALUE_25_X6 = "25X6"
    VALUE_25_X7 = "25X7"
    VALUE_25_X8 = "25X8"
    VALUE_25_X9 = "25X9"
